#!/bin/sh

# Licensed Materials - Property of Ricoh Production Print Solutions.
# Restricted Materials of Ricoh Production Print Solutions.
#
# (C) Copyright Ricoh Production Print Solutions 2009,2021. All rights reserved.

OS=linux
TF_PATH=/opt/infoprint/itm
TF_ZIP_PATH=$TF_PATH/tools/respack/$OS
TF_EJZ_PATH=$TF_PATH/ejz
TF_WS_PATH=$TF_EJZ_PATH/ws
TF_WEBAPPS_PATH=$TF_WS_PATH/webapps
TF_WS_LIB_PATH=$TF_WS_PATH/lib
TF_WEBINF_LIB_PATH=$TF_WEBAPPS_PATH/itm/WEB-INF/lib
LOG4J_NEW_VER=2.17.0
SET_ENV_FILE=$TF_WS_PATH/bin/setenv.sh
OWNERSHIP=`ls -l $SET_ENV_FILE | awk '{print $3 ":" $4}'`

# stop ejz
$TF_EJZ_PATH/bin/stopejz.sh

# delete the log4j libraries in itm.war
zip -d $TF_WEBAPPS_PATH/itm.war "WEB-INF/lib/log4j-core-2.*.jar" > /dev/null 2>&1
zip -d $TF_WEBAPPS_PATH/itm.war "WEB-INF/lib/log4j-api-2.*.jar" > /dev/null 2>&1

# remove the old files from TF_WS_LIB_PATH
rm $TF_WS_LIB_PATH/log4j-api-2.*.jar > /dev/null 2>&1
rm $TF_WS_LIB_PATH/log4j-core-2.*.jar > /dev/null 2>&1
rm $TF_WS_LIB_PATH/log4j-jul-2.*.jar > /dev/null 2>&1

# remove the old files from TF_WEBINF_LIB_PATH
rm $TF_WEBINF_LIB_PATH/log4j-api-2.*.jar > /dev/null 2>&1
rm $TF_WEBINF_LIB_PATH/log4j-core-2.*.jar > /dev/null 2>&1

# copy the new library
cp ./log4j-api-$LOG4J_NEW_VER.jar $TF_WS_LIB_PATH > /dev/null 2>&1
chown $OWNERSHIP $TF_WS_LIB_PATH/log4j-api-$LOG4J_NEW_VER.jar > /dev/null 2>&1
chmod 755 $TF_WS_LIB_PATH/log4j-api-$LOG4J_NEW_VER.jar > /dev/null 2>&1
cp ./log4j-core-$LOG4J_NEW_VER.jar $TF_WS_LIB_PATH > /dev/null 2>&1
chown $OWNERSHIP $TF_WS_LIB_PATH/log4j-core-$LOG4J_NEW_VER.jar > /dev/null 2>&1
chmod 755 $TF_WS_LIB_PATH/log4j-core-$LOG4J_NEW_VER.jar > /dev/null 2>&1
cp ./log4j-jul-$LOG4J_NEW_VER.jar $TF_WS_LIB_PATH > /dev/null 2>&1
chown $OWNERSHIP $TF_WS_LIB_PATH/log4j-jul-$LOG4J_NEW_VER.jar > /dev/null 2>&1
chmod 755 $TF_WS_LIB_PATH/log4j-jul-$LOG4J_NEW_VER.jar > /dev/null 2>&1

# replace the version in setenv.sh
cat $SET_ENV_FILE | sed "s/log4j-api-2.[0-9]*.[0-9]*.jar/log4j-api-$LOG4J_NEW_VER.jar/g; s/log4j-core-2.[0-9]*.[0-9]*.jar/log4j-core-$LOG4J_NEW_VER.jar/g; s/log4j-jul-2.[0-9]*.[0-9]*.jar/log4j-jul-$LOG4J_NEW_VER.jar/g" > "setenv.tmp"
mv "setenv.tmp" $SET_ENV_FILE
chown $OWNERSHIP $SET_ENV_FILE
chmod 755 $SET_ENV_FILE

# start ejz
$TF_EJZ_PATH/bin/startejz.sh

echo "Patch applied successfully. Current version of Log4j libraries is $LOG4J_NEW_VER."
